import os.path

import SCons.Util
import SCons.Errors
import SCons.Node.FS
import SCons.Builder


def _emitter(target, source, env):
    """Manipulate target and source lists."""
    sources = []
    for src in source:
        src = str(src)
        if os.path.isdir(src) and os.path.exists(os.path.join(src,
            '__init__.py')):
            # Register dependency on package contents
            for dpath, dnames, fnames in os.walk(src):
                for i, dname in enumerate(dnames):
                    if not os.path.exists(os.path.join(dname, '__init__.py')):
                        # Not a package, ignore
                        del dnames[i]
                env.Depends(target, [os.path.join(dpath, fname) for fname in
                    fnames if os.path.splitext(fname)[1] == '.py'])
        else:
            raise SCons.Errors.UserError('Invalid epydoc source \'%s\'' % src)

    return [os.path.join(str(target[0]), 'index.html')], source

def generate(env):
    env['EPYDOCFLAGS'] = SCons.Util.CLVar('')
    env['BUILDERS']['Epydoc'] = SCons.Builder.Builder(action='epydoc $SOURCES '
            '-o ${TARGET.dir} $EPYDOCFLAGS',
            source_factory=env.Entry, target_factory=env.Entry, emitter=_emitter)


def exists(env):
    return env.WhereIs('epydoc') is not None
