"""Test labeling points and cells."""
import sys
import os.path
import numpy
import time

sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import viper

idtype = viper.get_vtk_idtype()

vertices1 = numpy.array([[0.0, 0.0, 0.0],
                        [1.0, 0.0, 0.0],
                        [0.0, 1.0, 0.0],
                        [1.0, 1.0, 0.0],
                        [2.0, 0.0, 0.0],
                        [0.0, 2.0, 0.0],
                        [2.0, 1.0, 0.0],
                        [1.0, 2.0, 0.0],
                        [2.0, 2.0, 0.0]])
cells = numpy.array([[0, 1, 2], [1, 2, 3], [1, 4, 3], [4, 3, 6], [2, 3, 5],
                        [3, 5, 7], [3, 6, 7], [6, 7, 8]], dtype=idtype)
scalars = numpy.linspace(0, 2, len(vertices1))

vertices2 = numpy.array([[0.0,0.0,0.0],
                        [1.0,0.0,0.0],
                        [0.0,1.0,0.0],
                        [1.0,1.0,0.0],
                        [2.0,0.0,0.0],
                        [0.0,2.0,0.0],
                        [2.0,1.0,0.0],
                        [1.0,2.0,0.0],
                        [2.0,2.0,0.0]])
triangles = numpy.array([[0,1,2],[1,2,3],[1,4,3],[4,3,6],[2,3,5],
                        [3,5,7],[3,6,7],[6,7,8]], dtype=idtype)

viper.set_default_lut(os.path.join(os.path.dirname(viper.__file__), "data",
    "gauss_120.lut"))

actors = [viper.ScalarField(vertices1, cells, scalars), viper.Sphere((0.5, 0.5, 0), 0.2, 30, 20,
    actor_kwds={"color": (1, 0, 0)})]
actors[0].is_point_labels_enabled = True
vip = viper.Viper(actors)
actors[1].is_point_labels_enabled = True

win = viper.VtkWindow(vip)
win.interactive()

# Disable point labels on first actor
actors[0].is_point_labels_enabled = False
# Remove second actor and point labels with it (automatic)
vip.remove_actor(actors[1])
win.render()
win.interactive()

# Enable (only) cell labels on second actor
actors[1].is_point_labels_enabled = False
actors[1].is_cell_labels_enabled = True
vip.add_actor(actors[1])
win.render()
win.interactive()
