"""Test movie generation.

This script accepts a commandline option, --offscreen, that enables offscreen
rendering. Note that at least on Linux, you will need special support in VTK,
while on Windows this should work out of the box.
"""
import numpy
import os.path
import sys
import optparse
import logging

sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
from viper import Viper, ScalarField
import viper


idtype = viper.get_vtk_idtype()


optparser = optparse.OptionParser()
optparser.add_option("-s", "--offscreen", help="enable offscreen rendering",
        action="store_true", default=False)
opts, args = optparser.parse_args()


coords2d = numpy.array([[0.0,0.0,0.0],
                        [1.0,0.0,0.0],
                        [0.0,1.0,0.0],
                        [1.0,1.0,0.0],
                        [2.0,0.0,0.0],
                        [0.0,2.0,0.0],
                        [2.0,1.0,0.0],
                        [1.0,2.0,0.0],
                        [2.0,2.0,0.0]])

triangles = numpy.array([[0,1,2],[1,2,3],[1,4,3],[4,3,6],[2,3,5],
                        [3,5,7],[3,6,7],[6,7,8]], dtype=idtype)


scalars = numpy.linspace(0,1,len(coords2d))
lut_fname = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
    "data", "gauss_120.lut"))
field = ScalarField(coords2d, triangles, scalars, actor_kwds={"lut":
    viper.LookupTable(lut_fname)})
v = Viper([field])
win = viper.VtkWindow(v, title="Test Movie")
logging.getLogger().setLevel(logging.DEBUG)
if opts.offscreen:
    logging.info("Enabling offscreen rendering")
    win.is_offscreen = True
else:
    logging.info("Not enabling offscreen rendering")
maker = viper.MovieMaker(v, "movie.avi")
for i in xrange(50):
    v.azimuth(2)
    # Not entirely sure why this helps, but it does
    v.reset_camera(center=False)
    win.render()
    maker.capture_frame()
maker.make_movie()
