"""Test scalarbar functionality."""
import sys
import os.path
import numpy
import time

sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import viper

idtype = viper.get_vtk_idtype()

vertices1 = numpy.array([[0.0, 0.0, 0.0],
                        [1.0, 0.0, 0.0],
                        [0.0, 1.0, 0.0],
                        [1.0, 1.0, 0.0],
                        [2.0, 0.0, 0.0],
                        [0.0, 2.0, 0.0],
                        [2.0, 1.0, 0.0],
                        [1.0, 2.0, 0.0],
                        [2.0, 2.0, 0.0]])
cells = viper.CellArray([[0, 1, 2], [1, 2, 3], [1, 4, 3], [4, 3, 6], [2, 3, 5],
                        [3, 5, 7], [3, 6, 7], [6, 7, 8]])
scalars = numpy.linspace(0, 2, len(vertices1))

vertices2 = numpy.array([[0.0,0.0,0.0],
                        [1.0,0.0,0.0],
                        [0.0,1.0,0.0],
                        [1.0,1.0,0.0],
                        [2.0,0.0,0.0],
                        [0.0,2.0,0.0],
                        [2.0,1.0,0.0],
                        [1.0,2.0,0.0],
                        [2.0,2.0,0.0]])
triangles = numpy.array([[0,1,2],[1,2,3],[1,4,3],[4,3,6],[2,3,5],
                        [3,5,7],[3,6,7],[6,7,8]], dtype=idtype)

viper.set_default_lut(viper.LookupTable(os.path.join(os.path.dirname(viper.__file__),
    "data", "gauss_120.lut"), range=(numpy.min(scalars), numpy.max(scalars))))

# Display a scalarfield and a vectorfield, and a scalarbar for each
vip = viper.Viper([viper.ScalarField(vertices1, cells, scalars),
    viper.VectorField(vertices2, vertices2.copy(), cells=triangles)])
scalarbar1 = vip.get_scalarbar(vip.POS_N)
scalarbar1.actor = vip.actors[0]
scalarbar1.should_show = True
scalarbar2 = vip.get_scalarbar(vip.POS_S)
scalarbar2.actor = vip.actors[1]
scalarbar2.should_show = True

win = viper.VtkWindow(vip)
win.interactive()

# Hide second scalarbar
scalarbar2.should_show = False
win.render()
win.interactive()

# Remove first actor and first scalarbar with it (automatic)
vip.remove_actor(vip.actors[0])
# Change LUT of second actor, the second scalarbar should update itself
alt_lut = [[1, 0, 0, 1],
      [0, 1, 0, 1],
      [0, 0, 1, 1],
      [0, 0, 0, 1],
      [1, 1, 0, 1],
      [1, 0, 1, 1],
      [0, 1, 1, 1]
      ]
scalarbar2.should_show = True
vip.actors[0].lut = viper.LookupTable(alt_lut)
win.render()
win.interactive()
