"""This demo displays a scalarbar for two actors which share a lookup-table,
but have different scalar ranges.
"""
import numpy
import os.path
import sys
sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import time

import viper

coords2d = numpy.array([[0.0, 0.0, 0.0],
                        [1.0, 0.0, 0.0],
                        [0.0, 1.0, 0.0],
                        [1.0, 1.0, 0.0],
                        [2.0, 0.0, 0.0],
                        [0.0, 2.0, 0.0],
                        [2.0, 1.0, 0.0],
                        [1.0, 2.0, 0.0],
                        [2.0, 2.0, 0.0]])
triangles = viper.CellArray(numpy.array([[0, 1, 2], [1, 2, 3], [1, 4, 3], [4,
    3, 6], [2, 3, 5], [3, 5, 7], [3, 6, 7], [6, 7, 8]]))
# 0 -> 0.5
scal1 = numpy.linspace(0, 1, len(coords2d))*0.5

coords3d = numpy.array([[0,0,0],[1,0,0],
                        [0,1,0],[0,0,1]])
tets = viper.CellArray(numpy.array([[0,1,2,3]]))
# 0.5 -> 1
scal2 = numpy.linspace(0, 1, len(coords3d))*0.5+0.5

lut_fname = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
    "data", "gauss_120.lut"))
viper.set_default_lut(viper.LookupTable(lut_fname, range=(0, 1)))


fields = [viper.ScalarField(coords2d, triangles, scal1),
        viper.ScalarField(coords3d, tets, scal2)]
v = viper.Viper(fields)
bar = v.get_scalarbar(v.POS_N)
bar.actor = v.actors[0]
bar.should_show = True
win = viper.VtkWindow(v, title="Test Shared Lookup Table")
win.interactive()
