import numpy
import os.path
import sys
sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import viper


idtype = viper.get_vtk_idtype()

coords2d = numpy.array([[0.0,0.0,0.0],
                        [1.0,0.0,0.0],
                        [0.0,1.0,0.0],
                        [1.0,1.0,0.0],
                        [2.0,0.0,0.0],
                        [0.0,2.0,0.0],
                        [2.0,1.0,0.0],
                        [1.0,2.0,0.0],
                        [2.0,2.0,0.0]])

triangles = numpy.array([[0,1,2],[1,2,3],[1,4,3],[4,3,6],[2,3,5],
                        [3,5,7],[3,6,7],[6,7,8]], dtype=idtype)

coords3d = numpy.array([[0,0,0],[1,0,0],
                        [0,1,0],[0,0,1]])

tets = numpy.array([[0,1,2,3]], dtype=idtype)

viper.set_default_lut(os.path.realpath(os.path.join(os.path.dirname(
    viper.__file__), "data", "gauss_120.lut")))


def _create_viper(*args, **kwds):
    vip = viper.Viper(*args, **kwds)
    win = viper.VtkWindow(vip, title="Test Standalone")
    return vip, win


def _meshplot():
    vip, win = _create_viper([viper.Mesh(vertices=coords2d, cells=triangles,)])
    win.interactive()

def _scalarplot():
    x = numpy.linspace(0,1,len(coords2d))
    field = viper.ScalarField(vertices=coords2d,
        cells=triangles, scalars=x)
    vip, win = _create_viper([field])
    stop = 500
    for i in xrange(stop):
        field.opacity -= 0.002
        win.render()
    for i in xrange(stop):
        field.opacity += 0.002
        win.render()
    win.interactive()

def _scalarplot3d():
    x = numpy.linspace(0, 1, len(coords3d))
    vip, win = _create_viper([viper.ScalarField(vertices=coords3d, cells=tets,
        scalars=x, actor_kwds={"opacity":0.1})])
    win.interactive()
    field = viper.ScalarField(vertices=coords3d, cells=tets, scalars=x,
            cutplane_origin=(.0, .0, .1), cutplane_normal=(1, 0, 1))
    vip.clear()
    vip.add_actor(field)
    vip.reset_camera()
    win.render()
    stop = 400
    for i in xrange(stop):
        x += 1.0/stop
        field.update_source()
        win.render()
    for i in xrange(stop):
        x -= 1.0/stop
        field.update_source()
        win.render()
    win.interactive()

def _vectorplot():
    directions = coords2d.copy()
    field = viper.VectorField(coords2d, directions, cells=triangles)
    vip, win = _create_viper([field])
    win.render()
    for i in xrange(100):
        directions += 0.01
        field.update_source()
        win.render()
    for i in xrange(100):
        directions -= 0.01
        field.update_source()
        win.render()
    win.interactive()

def _displacementplot():
    scalars = numpy.linspace(0, 1, len(coords2d))
    displacement2d = 0.2*coords2d.copy()
    displacement2d[0,:-1] = -1
    field = viper.ScalarField(vertices=coords2d, cells=triangles, scalars=scalars,
            displacement=displacement2d)
    vip, win = _create_viper([field])
    inc = 0.005
    stop = 200
    for i in xrange(stop):
        displacement2d[0,:-1] -= inc
        field.update_displacement()
        win.render()
    for i in xrange(stop):
        displacement2d[0,:-1] += inc
        field.update_displacement()
        win.render()
    win.interactive()


if __name__ == "__main__":
    _meshplot()
    _scalarplot()
    _scalarplot3d()
    _vectorplot()
    _displacementplot()
