import numpy
import os.path
import sys
sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import time

import viper

idtype = viper.get_vtk_idtype()

coords2d = numpy.array([[0.0, 0.0, 0.0],
                        [1.0, 0.0, 0.0],
                        [0.0, 1.0, 0.0],
                        [1.0, 1.0, 0.0],
                        [2.0, 0.0, 0.0],
                        [0.0, 2.0, 0.0],
                        [2.0, 1.0, 0.0],
                        [1.0, 2.0, 0.0],
                        [2.0, 2.0, 0.0]])
coords2d[:,:2] += 0.75
triangles = numpy.array([[0, 1, 2], [1, 2, 3], [1, 4, 3], [4, 3, 6], [2, 3, 5],
        [3, 5, 7], [3, 6, 7], [6, 7, 8]], dtype=idtype)
scal1 = numpy.linspace(0, 1, len(coords2d))

coords3d = numpy.array([[0,0,0],[1,0,0],
                        [0,1,0],[0,0,1]])
tets = numpy.array([[0,1,2,3]], dtype=idtype)
scal2 = numpy.linspace(0, 20, len(coords3d))

lut_fname1 = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
    "data", "gauss_120.lut"))
lut_fname2 = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
    "data", "vif.lut"))
fields = [viper.ScalarField(coords2d, triangles, scal1,
        actor_kwds={"lut": viper.LookupTable(lut_fname1)}),
        viper.ScalarField(coords3d, tets, scal2, actor_kwds={"lut":
                viper.LookupTable(lut_fname2)})]
v = viper.Viper(fields)
scalarbar1 = v.get_scalarbar(v.POS_N)
scalarbar1.actor = v.actors[0]
scalarbar1.should_show = True
scalarbar2 = v.get_scalarbar(v.POS_S)
scalarbar2.actor = v.actors[1]
scalarbar2.should_show = True
win = viper.VtkWindow(v, title="Test Two Scalar Fields")

# Loop for 2 seconds, while changing scalars
scal1_inv = []
for i, s in enumerate(scal1):
    scal1_inv.append(numpy.linspace(s, 1-s, 50))

start_anim = time.time()
scal = fields[0].scalars
for i in range(50):
    start = time.time()
    # scal = numpy.array([scal1_inv[j][i] for j in range(len(scal1))], "d")
    # fields[0].data = scal
    # or, for efficiency (not visible in this test):
    scal[:] = numpy.array([scal1_inv[j][i] for j in range(len(scal1))], "d")
    fields[0].update_source()
    win.render()
    remain = 0.04 - (time.time() - start)
    if remain > 0:
        time.sleep(remain)
v.actors[0].scalar_range = (0, 0.1)
win.render()
print "Ran for %f seconds" % (time.time()-start_anim)
win.interactive()
