"""Demonstrate use of viper from within a WX window.
"""
import wx
import vtk
import sys
import os.path
sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))

import viper.wx
import numpy
from dolfin import UnitSquare


class MyFrame(wx.Frame):
    """The main wx window."""
    def __init__(self,parent, id, title, size):
        # super(MyFrame, self).__init__(parent, id, title, size=size)
        wx.Frame.__init__(self, parent, id, title)

        button = wx.Button(self, -1, label="Close")
        self.Bind(wx.EVT_BUTTON, self.OnButtonClick, button)

        label = wx.StaticText(self, -1, label=u'Viper wx widget example')
        label.SetBackgroundColour(wx.WHITE)
        label.SetForegroundColour(wx.BLACK)

        # vip = Viper(mesh=self.mesh, x=self.x, frame=self, warpscalar=True)

        square = UnitSquare(128, 128)
        coords = square.coordinates()
        scalars = numpy.sin(numpy.pi*coords[:, 0])*numpy.cos(numpy.pi*coords[:,
            1])
        lut_fname = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
            "data", "gauss_120.lut"))
        vip = viper.Viper([viper.ScalarField(coords, viper.CellArray(square.cells()), scalars,
            actor_kwds={"lut": viper.LookupTable(lut_fname)})])
        vip_win = viper.wx.Window(vip, self, size=size)

        # Would use GridBagSizer, but it won't resize properly
        sizer = wx.BoxSizer(wx.VERTICAL)
        border = 5
        sizer.Add(button, border=border, flag=wx.ALL)
        sizer.Add(vip_win, 2, flag=wx.EXPAND|wx.ALL, border=border)
        sizer.Add(label, border=border, flag=wx.ALL)
        self.SetSizerAndFit(sizer)

        self.Show(True)


    def OnButtonClick(self, event):
        sys.exit()


app = wx.App()
frame = MyFrame(None, -1, "wxViper", size=(400, 400))
app.MainLoop()
