import sys
import copy
import numpy
import  wx
import os.path

sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import vtk
import viper.wx
from dolfin import UnitSquare
from vtk.wx.wxVTKRenderWindow import wxVTKRenderWindow

radioOptions = ("Viper Controls",
                "Outline",
                "No outline",)

class wxViperDialog(wx.Dialog):
    def __init__(self, parent = None, ID = -1, title="wx Viper Dialog",
                   size=wx.DefaultSize, pos=wx.DefaultPosition, style=wx.DEFAULT_DIALOG_STYLE,):
        wx.Dialog.__init__(self, parent, ID, title, pos, size, style)

        self.Bind(wx.EVT_SIZE, self.OnSize)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)

        self.Hide()
        self.OnInit()
        self.CenterOnScreen()

    def viperRefresh(self):
        vtk = self.viper.ren.GetVTKWindow()
        vtk.Render()

    def OnSize(self, event):
        self.Refresh()
        event.Skip()

    def OnQuit(self, event):
        dlg = wx.MessageDialog(None, "Are you sure you want to exit?",
                                  'Quit?', wx.YES_NO | wx.ICON_QUESTION)
        result = dlg.ShowModal()
        if result == wx.ID_NO:
            return
        dlg.Destroy()
        self.Destroy()

    def handleRadioSelection(self, event):
        self.viper.toggle_outline()
        self.viperRefresh()

    def OnInit(self):
        #create object and viper
        square = UnitSquare(128, 128)
        coords = square.coordinates()
        scalars = numpy.sin(numpy.pi*coords[:, 0])*numpy.cos(numpy.pi*coords[:,1])
        lut_fname = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
                                                   "data", "gauss_120.lut"))
        self.viper = vip = viper.Viper([viper.ScalarField(coords, square.cells(),
                                         scalars,actor_kwds={"lut": lut_fname})])
        vtk_win = wxVTKRenderWindow(self, -1)
        vtk_win.GetRenderWindow().AddRenderer(vip.renderer)

        #create controls
        self.rb = rb = wx.RadioBox(self, -1, radioOptions[0], wx.DefaultPosition, wx.DefaultSize,
                radioOptions[1:5], 2, wx.RA_SPECIFY_COLS)
        rb.Bind(wx.EVT_RADIOBOX, self.handleRadioSelection)
        rb.SetSelection(1)

        #layout various widgets
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(vtk_win, 2, flag = wx.EXPAND, border = 5)
        sizer.Add(rb, 0, flag = wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, border = 5)
        self.addStandardButtons(sizer)
        self.SetSizerAndFit(sizer)

        self.Fit()
        sizer.Layout()

    def addStandardButtons(self, sizer):
        line = wx.StaticLine(self, -1, size=(20,-1), style=wx.LI_HORIZONTAL)
        btnsizer = wx.StdDialogButtonSizer()
        
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        btnsizer.AddButton(btn)
        self.okbtn = btn

        btn = wx.Button(self, wx.ID_CANCEL)
        btnsizer.AddButton(btn)
        btnsizer.Realize()
        sizer.Add(line, 0, wx.GROW|wx.ALIGN_CENTER_VERTICAL|wx.TOP, border = 5)
        sizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, border = 5)
        self.cancelbtn = btn

    def GetValue(self):
        return self.rb.GetStringSelection()

class ViperDialog:
    def __init__(self):
        td = wxViperDialog()
        if td.ShowModal() == wx.ID_OK:
            result = td.GetValue()
            print "result:", result
        else:
            result = None
        td.Destroy()
        self.rval = result


if __name__ == "__main__":
    app = wx.App(redirect = False)
    vd = ViperDialog()
    app.MainLoop()

