import sys
import copy
import numpy
import  wx
import os.path

sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import vtk
import viper.wx
from dolfin import UnitSquare
from vtk.wx.wxVTKRenderWindow import wxVTKRenderWindow

radioOptions = ("Viper Controls",
                "Outline",
                "No outline",)

class Frame(wx.Frame):
    def __init__(self, parent = None, ID = -1, title="wx Viper Frame",
            size=wx.DefaultSize, pos=wx.DefaultPosition):
        wx.Frame.__init__(self, parent, ID, title, pos, size)

        # self.Bind(wx.EVT_SIZE, self.OnSize)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)

        self.Hide()
        self.CenterOnScreen()


        panel = wx.Panel(self, -1)
        
        #create object and viper
        square = UnitSquare(128, 128)
        coords = square.coordinates()
        scalars = numpy.sin(numpy.pi*coords[:, 0])*numpy.cos(numpy.pi*coords[:,1])
        lut_fname = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
                                                   "data", "gauss_120.lut"))
        self.viper = vip = viper.Viper([viper.ScalarField(coords, square.cells(),
                                         scalars,actor_kwds={"lut": lut_fname})])
        vip_win = viper.wx.Window(vip, parent=panel, size=wx.Size(640, 480))

        #create controls
        self.rb = rb = wx.RadioBox(panel, -1, radioOptions[0],
                wx.DefaultPosition, wx.DefaultSize, radioOptions[1:5], 2,
                wx.RA_SPECIFY_COLS)
        rb.Bind(wx.EVT_RADIOBOX, self.handleRadioSelection)
        rb.SetSelection(1)
        btn = wx.Button(panel, -1, "Done")
        btn.Bind(wx.EVT_BUTTON, self.OnQuit)


        # Lay out the panel
        pansizer = wx.BoxSizer(wx.VERTICAL)
        pansizer.Add(vip_win, 2, flag=wx.EXPAND, border=5)
        pansizer.Add(btn, 0, flag=wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, border=5)
        pansizer.Add(rb, 0, flag=wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, border=5)
        pansizer.Layout()
        panel.SetSizerAndFit(pansizer)

        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(panel, 2, flag=wx.EXPAND)
        sizer.Layout()
        self.SetSizerAndFit(sizer)

    def viperRefresh(self):
        vtk = self.viper.ren.GetVTKWindow()
        vtk.Render()

    def OnQuit(self, event):
        dlg = wx.MessageDialog(self, "Are you sure you want to exit?",
                                  'Quit?', wx.YES_NO|wx.NO_DEFAULT|wx.ICON_QUESTION)
        result = dlg.ShowModal()
        if result == wx.ID_NO:
            return
        dlg.Destroy()
        self.Destroy()

    def handleRadioSelection(self, event):
        self.viper.toggle_outline()
        self.viperRefresh()

if __name__ == "__main__":
    app = wx.App(redirect = False)
    td = Frame()
    td.Show(True)
    app.MainLoop()

