import sys
import copy
import numpy
import  wx
import os.path

sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
import vtk
import viper.wx
from vtk.wx.wxVTKRenderWindowInteractor import wxVTKRenderWindowInteractor
idtype = viper.get_vtk_idtype()

coords2d = numpy.array([[0.0,0.0,0.0],
                        [1.0,0.0,0.0],
                        [0.0,1.0,0.0],
                        [1.0,1.0,0.0],
                        [2.0,0.0,0.0],
                        [0.0,2.0,0.0],
                        [2.0,1.0,0.0],
                        [1.0,2.0,0.0],
                        [2.0,2.0,0.0]])

triangles = numpy.array([[0,1,2],[1,2,3],[1,4,3],[4,3,6],[2,3,5],
                        [3,5,7],[3,6,7],[6,7,8]], dtype=idtype)

coords3d = numpy.array([[0,0,0],[1,0,0],
                        [0,1,0],[0,0,1]])

tets = numpy.array([[0,1,2,3]], dtype=idtype)



radioOptions = ("Viper Controls",
                "Outline",
                "No outline",)

class wxVtkFrame(wx.Frame):
    def __init__(self, parent = None, ID = -1, title="wx vtk Frame", size=wx.DefaultSize, pos=wx.DefaultPosition):
        wx.Frame.__init__(self, parent, ID, title, pos, size)

        self.Bind(wx.EVT_SIZE, self.OnSize)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)

        self.Hide()
        self.OnInit()
        self.CenterOnScreen()

    def viperRefresh(self):
        vtk = self.viper.ren.GetVTKWindow()
        vtk.Render()

    def OnSize(self, event):
        self.Refresh()
        event.Skip()

    def OnQuit(self, event):
        dlg = wx.MessageDialog(None, "Are you sure you want to exit?",
                                  'Quit?', wx.YES_NO | wx.ICON_QUESTION)
        result = dlg.ShowModal()
        if result == wx.ID_NO:
            return
        dlg.Destroy()
        self.Destroy()

    def handleRadioSelection(self, event):
        pass
        #self.viper.toggle_outline()
        #self.viperRefresh()

    def OnInit(self):
        panel = wx.Panel(self, -1)
        
        # create the widget
        widget = wxVTKRenderWindowInteractor(panel, -1, size = wx.Size(100,100))
        self.widget = widget
        coords = coords2d.copy()
	cells = triangles
        scalars = numpy.sin(numpy.pi*coords[:, 0])*numpy.cos(numpy.pi*coords[:,1])
        lut_fname = os.path.realpath(os.path.join(os.path.dirname(viper.__file__),
                                                   "data", "gauss_120.lut"))
        self.viper = vip = viper.Viper([viper.ScalarField(coords, cells,
                                         scalars,actor_kwds={"lut": lut_fname})])
        widget.GetRenderWindow().AddRenderer(vip.renderer)

        #create controls
        self.rb = rb = wx.RadioBox(panel, -1, radioOptions[0], wx.DefaultPosition, wx.DefaultSize,
                radioOptions[1:5], 2, wx.RA_SPECIFY_COLS)
        rb.Bind(wx.EVT_RADIOBOX, self.handleRadioSelection)
        btn = wx.Button(panel, -1, "Done")
        self.Bind(wx.EVT_BUTTON, self.OnQuit, btn)
        rb.SetSelection(1)

        #layout various widgets
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(widget, 2, flag = wx.EXPAND, border = 5)
        sizer.Add(btn, 0, flag = wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, border = 5)
        sizer.Add(rb, 0, flag = wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, border = 5)
        panel.SetSizerAndFit(sizer)

        self.Fit()
        sizer.Layout()

if __name__ == "__main__":
    app = wx.App(redirect = False)
    td = wxVtkFrame()
    td.Show(True)
    app.MainLoop()


