import vtk
import sys


on_windows = sys.platform.startswith("win")


class WidgetBase(object):
    """Base for Viper widgets.
    @ivar viper: Associated L{Viper}.
    @ivar is_offscreen: Are we in offscreen mode?
    """
    def __init__(self, vip):
        self.viper = vip
        self.__is_offscreen = False


    def __get_offscreen(self):
        return self.__is_offscreen

    def __set_offscreen(self, offscreen):
        if on_windows:
            self.vtk_window.SetOffScreenRendering(offscreen)
        else:
            graphics_fact = vtk.vtkGraphicsFactory()
            imaging_fact = vtk.vtkImagingFactory()
            graphics_fact.SetOffScreenOnlyMode(offscreen)
            graphics_fact.SetUseMesaClasses(offscreen)
            imaging_fact.SetUseMesaClasses(offscreen)

        self.__is_offscreen = offscreen

    is_offscreen = property(__get_offscreen, __set_offscreen)
